octogrid
========

    command line tool to export your GitHub network in GML format

.. image:: https://img.shields.io/pypi/v/octogrid.svg?style=flat-square
    :target: https://pypi.python.org/pypi/octogrid/
    :alt: Latest Version
    
.. image:: https://img.shields.io/badge/Python-2.6%2C%202.7-brightgreen.svg?style=flat-square
    :target: https://pypi.python.org/pypi/octogrid/
    :alt: Supported Python versions
    
.. image:: https://img.shields.io/pypi/l/octogrid.svg?style=flat-square
    :target: https://pypi.python.org/pypi/octogrid/
    :alt: License

.. image:: https://img.shields.io/pypi/dm/octogrid.svg?style=flat-square
    :target: https://pypi.python.org/pypi/octogrid/
    :alt: Downloads

Installation
~~~~~~~~~~~~
    pip install octogrid

Usage
~~~~~
	octogrid export [--user=<username>]

octogrid in action
~~~~~~~~~~~~~~~~~~
.. figure:: https://raw.githubusercontent.com/pravj/octogrid/master/docs/github-network.png
   :alt: Communities in GitHub Following Network for @pravj
